Enum spl_token::error::TokenError
source · [−]pub enum TokenError {
Show 20 variants
NotRentExempt,
InsufficientFunds,
InvalidMint,
MintMismatch,
OwnerMismatch,
FixedSupply,
AlreadyInUse,
InvalidNumberOfProvidedSigners,
InvalidNumberOfRequiredSigners,
UninitializedState,
NativeNotSupported,
NonNativeHasBalance,
InvalidInstruction,
InvalidState,
Overflow,
AuthorityTypeNotSupported,
MintCannotFreeze,
AccountFrozen,
MintDecimalsMismatch,
NonNativeNotSupported,
}Expand description
Errors that may be returned by the Token program.
Variants
NotRentExempt
Lamport balance below rent-exempt threshold.
InsufficientFunds
Insufficient funds for the operation requested.
InvalidMint
Invalid Mint.
MintMismatch
Account not associated with this Mint.
OwnerMismatch
Owner does not match.
FixedSupply
This token’s supply is fixed and new tokens cannot be minted.
AlreadyInUse
The account cannot be initialized because it is already being used.
InvalidNumberOfProvidedSigners
Invalid number of provided signers.
InvalidNumberOfRequiredSigners
Invalid number of required signers.
UninitializedState
State is uninitialized.
NativeNotSupported
Instruction does not support native tokens
NonNativeHasBalance
Non-native account can only be closed if its balance is zero
InvalidInstruction
Invalid instruction
InvalidState
State is invalid for requested operation.
Overflow
Operation overflowed
AuthorityTypeNotSupported
Account does not support specified authority type.
MintCannotFreeze
This token mint cannot freeze accounts.
AccountFrozen
Account is frozen; all account operations will fail
MintDecimalsMismatch
Mint decimals mismatch between the client and mint
NonNativeNotSupported
Instruction does not support non-native tokens