#[repr(u8)]pub enum AccountState {
Uninitialized = 0,
Initialized = 1,
Frozen = 2,
}Expand description
Account state.
Variants
Uninitialized = 0
Account is not yet initialized
Initialized = 1
Account is initialized; the account owner and/or delegate may perform permitted operations on this account
Frozen = 2
Account has been frozen by the mint freeze authority. Neither the account owner nor the delegate are able to perform operations on this account.