Mint

Struct Mint 

#[repr(C)]
pub struct Mint { pub mint_authority: COption<Address>, pub supply: u64, pub decimals: u8, pub is_initialized: bool, pub freeze_authority: COption<Address>, }
Mint data.

Fields

mint_authority: COption<Address>

Optional authority used to mint new tokens. The mint authority may only be provided during mint creation. If no mint authority is present then the mint has a fixed supply and no further tokens may be minted.

supply: u64

Total supply of tokens.

decimals: u8

Number of base 10 digits to the right of the decimal place.

is_initialized: bool

Is true if this structure has been initialized

freeze_authority: COption<Address>

Optional authority to freeze token accounts.